AudioTrack class

A representation of a audio track.

Inheritance

Constructors

AudioTrack({required int trackId, TrackType trackType = TrackType.audio, required String mimetype, required String language, required int channel, required int bitrate})
Creates an instance of AudioTrack.

Properties

bitrate → int
The bitrate of audio track.
final
channel → int
The channel of audio track.
final
hashCode → int
The hash code for this object.
no setterinherited
language → String
The language of audio track.
final
mimetype → String
The strack mime type.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackId → int
The track id of track that uses to determine track.
finalinherited
trackType → TrackType
The type of the track.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited