Caption class sealed

A representation of a single caption.

A typical closed captioning file will include several Captions, each linked to a start and end time.

Implementers
Annotations

Properties

end → Duration
When in the given video should this Caption be dismissed.
final
hashCode → int
The hash code for this object.
no setterinherited
number → int
The number that this caption was assigned.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Duration
When in the given video should this Caption begin displaying.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited