PictureCaption class

A representation of a picture-based caption.

Inheritance
Annotations

Constructors

PictureCaption({required int number, required Duration start, required Duration end, Uint8List? picture, double? pictureWidth, double? pictureHeight})
Creates a new PictureCaption object.
const

Properties

end → Duration
When in the given video should this Caption be dismissed.
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
number → int
The number that this caption was assigned.
finalinherited
picture → Uint8List?
The image data for the caption, typically in a format like PNG or JPEG.
final
pictureHeight → double?
Specifies the picture's height.
final
pictureWidth → double?
Specifies the picture's width.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Duration
When in the given video should this Caption begin displaying.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

none → const PictureCaption
A no picture caption object. This is a caption with start and end durations of zero, and an empty picture.