SubtitleAttribute class

A representation of a single attribute.

The subtitle attributes of the video.

Annotations

Constructors

SubtitleAttribute({required SubtitleAttrType attrType, required int startTime, required int stopTime, required Object attrValue})
Creates a new instance of SubtitleAttribute.
const

Properties

attrType → SubtitleAttrType
Subtitle attribute type of the video.
final
attrValue → Object
Subtitle attribute value of the video.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startTime → int
Subtitle start time of the video.
final
stopTime → int
Subtitle stop time of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEventSubtitleAttrList(List? eventSubtitleAttrList) → List<SubtitleAttribute>
Parse a subtitle attribute list from the subtitle attribute list which given by eventListener.