TextCaption class

A representation of a text-based caption.

Inheritance
Annotations

Constructors

TextCaption({required int number, required Duration start, required Duration end, required String text, List<SubtitleAttribute?>? subtitleAttributes, TextStyle? textStyle, TextOriginAndExtent? textOriginAndExtent, AlignmentGeometry? textAlign, Color? windowBgColor, double? fontSize, Paint? fontForeground})
Creates a new TextCaption object.
const

Properties

end → Duration
When in the given video should this Caption be dismissed.
finalinherited
fontForeground → Paint?
The outline of the text in the closed caption.
final
fontSize → double?
The font size of the text in the closed caption.
final
hashCode → int
The hash code for this object.
no setteroverride
number → int
The number that this caption was assigned.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → Duration
When in the given video should this Caption begin displaying.
finalinherited
subtitleAttributes → List<SubtitleAttribute?>?
The subtitle attributes associated with this caption.
final
text → String
The actual text that should appear on screen to be read between start and end.
final
textAlign → AlignmentGeometry?
The alignment of the text in the closed caption.
final
textOriginAndExtent → TextOriginAndExtent?
The origin and extent of the text in the closed caption.
final
textStyle → TextStyle?
Specifies how the text in the closed caption should look.
final
windowBgColor → Color?
The background color of the window where the text appears.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

processSubtitleAttributes(List<SubtitleAttribute> subtitleAttributes) → (TextOriginAndExtent?, TextStyle?, AlignmentGeometry, Color, double, Paint)
Process subtitle attributes and return the text alignment and text style.

Constants

lengthARGB → const int
The length of the hexadecimal string representing an ARGB color.
lengthRGB → const int
The length of the hexadecimal string representing an RGB color.
none → const TextCaption
A no text caption object. This is a caption with start and end durations of zero, and an empty text string.