TextTrack class

A representation of a text track.

Inheritance

Constructors

TextTrack({required int trackId, TrackType trackType = TrackType.text, required String mimetype, required String language})
Creates an instance of TextTrack.

Properties

hashCode → int
The hash code for this object.
no setterinherited
language → String
The language of text track.
final
mimetype → String
The strack mime type.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackId → int
The track id of track that uses to determine track.
finalinherited
trackType → TrackType
The type of the track.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited