Track class

A representation of a single track.

A typical video file will include several Tracks.Such as VideoTracks, AudioTracks, TextTracks.

Implementers

Constructors

Track({required int trackId, required TrackType trackType, required String mimetype})
Creates an instance of Track.
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
mimetype → String
The strack mime type.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackId → int
The track id of track that uses to determine track.
final
trackType → TrackType
The type of the track.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited