VideoTrack class

A representation of a video track.

Inheritance

Constructors

VideoTrack({required int trackId, TrackType trackType = TrackType.video, required String mimetype, required int width, required int height, required int bitrate})
Creates an instance of VideoTrack.

Properties

bitrate → int
The bitrate of video track.
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of video track.
final
mimetype → String
The strack mime type.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trackId → int
The track id of track that uses to determine track.
finalinherited
trackType → TrackType
The type of the track.
finalinherited
width → int
The width of video track.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited