VideoEvent class

Event emitted from the platform implementation.

Annotations

Constructors

VideoEvent({required VideoEventType eventType, DurationRange? duration, Size? size, int? buffered, bool? isPlaying, Map<Object?, Object?>? adInfo, String? manifestInfo, SubtitlesInfo? subtitlesInfo})
Creates an instance of VideoEvent.

Properties

adInfo → Map<Object?, Object?>?
The ad info from dash.
final
buffered → int?
Buffered size of the video.
final
duration → DurationRange?
Duration of the video.
final
eventType → VideoEventType
The type of the event.
final
hashCode → int
The hash code for this object.
no setteroverride
isPlaying → bool?
Whether the video is currently playing.
final
manifestInfo → String?
The manifest information in dash.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → Size?
Size of the video.
final
subtitlesInfo → SubtitlesInfo?
The subtitle information of the video.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override