VideoPlayerOptions class

VideoPlayerOptions can be optionally used to set additional player settings

Annotations

Constructors

VideoPlayerOptions({bool mixWithOthers = false, bool allowBackgroundPlayback = false})
set additional optional player settings

Properties

allowBackgroundPlayback → bool
Set this to true to keep playing video in background, when app goes in background. The default value is false.
final
hashCode → int
The hash code for this object.
no setterinherited
mixWithOthers → bool
Set this to true to mix the video players audio with other audio sources. The default value is false
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited