ClosedCaption constructor
Creates a a new closed caption, designed to be used with
VideoPlayerValue.textCaption and VideoPlayerValue.pictureCaption.
If text is null or empty, nothing will be displayed.
Implementation
const ClosedCaption({super.key, this.captions, this.customTextStyle});